@@ -29,7 +29,7 @@ class DefaultExceptionHandler:
         # response.body = self.errors_env.get_template(
         #     "error-500.html").render({"error": error}).encode()
 
-    def handle_404(self, response):
+    def handle_404(self):
         return PlainTextResponse("ERROR 404")
 
         # response.body = self.errors_env.get_template(
